summaryrefslogtreecommitdiffstats
path: root/base/tracked_objects.h
diff options
context:
space:
mode:
Diffstat (limited to 'base/tracked_objects.h')
-rw-r--r--base/tracked_objects.h10
1 files changed, 4 insertions, 6 deletions
diff --git a/base/tracked_objects.h b/base/tracked_objects.h
index c0674cc..9b7f111 100644
--- a/base/tracked_objects.h
+++ b/base/tracked_objects.h
@@ -442,17 +442,15 @@ class BASE_EXPORT ThreadData {
// PROFILING_ACTIVE (i.e., it can't be set to a higher level than what is
// compiled into the binary, and parent-child tracking at the
// PROFILING_CHILDREN_ACTIVE level might not be compiled in).
- static bool InitializeAndSetTrackingStatus(Status status);
-
- static Status status();
+ static bool InitializeAndSetTrackingStatus(bool status);
// Indicate if any sort of profiling is being done (i.e., we are more than
// DEACTIVATED).
- static bool TrackingStatus();
+ static bool tracking_status();
// For testing only, indicate if the status of parent-child tracking is turned
- // on. This is currently a compiled option, atop TrackingStatus().
- static bool TrackingParentChildStatus();
+ // on. This is currently a compiled option, atop tracking_status().
+ static bool tracking_parent_child_status();
// Special versions of Now() for getting times at start and end of a tracked
// run. They are super fast when tracking is disabled, and have some internal